==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicMarkerSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesDescriptionMetadata } from "./GeographicMarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicMarkerSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicMarkerSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicMarkerSeriesBaseDescriptionMetadata.a == null) {
                GeographicMarkerSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicMarkerSeriesBaseDescriptionMetadata.c(GeographicMarkerSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicMarkerSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicMarkerSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMarkerSeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicMarkerSeriesBaseDescriptionMetadata.b(a);
            a.ac("GeographicMarkerSeriesBase", GeographicMarkerSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicMarkerSeriesBaseDescriptionMetadata.$t = markType(GeographicMarkerSeriesBaseDescriptionMetadata, 'GeographicMarkerSeriesBaseDescriptionMetadata');
    GeographicMarkerSeriesBaseDescriptionMetadata.a = null;
    return GeographicMarkerSeriesBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicMarkerSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesDescriptionMetadata } from "./GeographicMarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicMarkerSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicMarkerSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicMarkerSeriesBaseDescriptionMetadata.a == null) {
                GeographicMarkerSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicMarkerSeriesBaseDescriptionMetadata.c(GeographicMarkerSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicMarkerSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicMarkerSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMarkerSeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicMarkerSeriesBaseDescriptionMetadata.b(a);
            a.ad("GeographicMarkerSeriesBase", GeographicMarkerSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicMarkerSeriesBaseDescriptionMetadata.$t = markType(GeographicMarkerSeriesBaseDescriptionMetadata, 'GeographicMarkerSeriesBaseDescriptionMetadata');
    GeographicMarkerSeriesBaseDescriptionMetadata.a = null;
    return GeographicMarkerSeriesBaseDescriptionMetadata;
})();
